<?php



namespace WpieApp\Core\Admin;

use WpieApp\Core\Helpers\Helper;

defined( 'WPIE__FILE__' ) || exit;


class Requirement {

        
        private static $wordpress_version = '4.4';

        
        private static $php_version = '5.6';

        
        private static $messages = [];

        
        public static function check() {

                // Check WordPress version.
                if ( version_compare( \get_bloginfo( 'version' ), self::$wordpress_version, '<' ) ) {
                         /* translators: %s: WordPress Version */
                        self::$messages[] = sprintf( esc_html__( 'WP Import Export requires WordPress version %s or above. Please update WordPress to run this plugin.', 'wp-import-export' ), self::$wordpress_version );
                }

                // Check PHP version.
                if ( version_compare( phpversion(), self::$php_version, '<' ) ) {
                        /* translators: %s: PHP Version */
                        self::$messages[] = sprintf( esc_html__( 'WP Import Export requires PHP version %s or above. Please update PHP to run this plugin.', 'wp-import-export' ), self::$php_version );
                }

                if ( WPIE_WC_ONLY && !Helper::hasRequiredPlugin( 'WooCommerce', '3.4' ) ) {
                        self::$messages[] = esc_html__( 'WP Import Export requires WooCommerce 3.4 or higher. Please install and activate WooCommerce to enable this plugin', 'wp-import-export' );
                }

                if ( !Helper::isNonEmptyArray( self::$messages ) ) {
                        return true;
                }

                // Auto-deactivate plugin.
                \add_action( 'admin_init', [ __CLASS__, 'auto_deactivate' ] );

                \add_action( 'admin_notices', [ __CLASS__, 'activation_error' ] );

                return false;
        }

        
        public static function auto_deactivate() {
                \deactivate_plugins( WPIE_BASENAME );

                if ( isset( $_GET[ 'activate' ] ) ) {
                        unset( $_GET[ 'activate' ] );
                }
        }

        
        public static function activation_error() {
                /* translators: %s: Error messages */
                echo \wp_kses_post( sprintf( '<div class="notice notice-error">%s</div>', \wpautop( join( '<br />', self::$messages ) ) ) );
        }
}
