<?php



namespace WpieApp\Core\Helpers;

defined( 'WPIE__FILE__' ) || exit;


trait Arrays {

        
        public static function isNonEmptyArray( $array = null ) {

                if ( is_array( $array ) && !empty( $array ) ) {
                        return true;
                }
                return false;
        }

        
        public static function arrHasNumVal( $array = [] ) {

                return Helper::isNonEmptyArray( $array ) && $array == array_filter( $array, 'is_numeric' );
        }

        
        public static function arrFirst( $array = [] ) {
                return count( $array ) > 0 ? reset( $array ) : null;
        }

        
        public static function arrLast( $array = [] ) {
                return count( $array ) ? end( $array ) : null;
        }

        
        public static function arrTostr( $array = [], $sep = ',', $rightTrim = true ) {

                if ( !Helper::isNonEmptyArray( $array ) ) {
                        return "";
                }

                $sep = Helper::isNonEmptyStr( $sep ) ? $sep : ',';

                $data = self::isMultidimensional( $array ) ? Helper::jsonEncode( $array ) : implode( $sep, $array );

                if ( !Helper::isNonEmptyStr( $data ) ) {
                        return '';
                }

                return Helper::strTrim( $data, $sep ) === "" ? "" : ($rightTrim ? Helper::rightTrim( $data, $sep ) : $data);
        }

        
        public static function isMultidimensional( $array = [] ) {

                if ( !Helper::isNonEmptyArray( $array ) ) {
                        return false;
                }

                $isMultiDim = false;

                foreach ( $array as $element ) {
                        if ( is_array( $element ) ) {
                                $isMultiDim = true;
                                break; // If at least one element is an array, it's multi-dimensional.
                        }
                }

                return $isMultiDim;
        }

        
        public static function isAssociativeArray( $array ) {
                return count( array_filter( array_keys( $array ), 'is_string' ) ) > 0;
        }

        
        public static function createUniqueArray( $array = [], $undefindKey = 'undefind_' ) {

                if ( !Helper::isNonEmptyArray( $array ) ) {
                        return [];
                }

                $newArr = [];

                $uCount = 1;

                foreach ( $array as $key ) {

                        $key = Helper::sanitizeKey( $key );

                        if ( !Helper::isNonEmptyStr( $key ) ) {
                                $key = $undefindKey . $uCount;
                                $uCount++;
                        }

                        if ( in_array( $key, $newArr ) ) {

                                $count = 1;

                                $tempKey = $key;

                                while ( in_array( $tempKey, $newArr ) ) {
                                        $tempKey = $key . "_" . $count;
                                        $count++;
                                }

                                $key = $tempKey;
                        }
                        $newArr[] = $key;
                }


                return $newArr;
        }

        
        public static function sortBy( $arr = [], $orderBy = "order" ) {

                if ( !Helper::isNonEmptyArray( $arr ) || Helper::isEmptyStr( $orderBy ) ) {
                        return $arr;
                }

                uasort( $arr, function ( $firstArr, $nextArr ) use ( $orderBy ) {
                        $firstArr[ $orderBy ] = isset( $firstArr[ $orderBy ] ) ? Helper::toNumber( $firstArr[ $orderBy ] ) : 100;
                        $nextArr[ $orderBy ]  = isset( $nextArr[ $orderBy ] ) ? Helper::toNumber( $nextArr[ $orderBy ] ) : 100;
                        return $firstArr[ $orderBy ] > $nextArr[ $orderBy ] ? 1 : -1;
                } );

                return $arr;
        }

        
        public static function subArray( $arr = [], $path = "" ) {

                if ( !Helper::isNonEmptyArray( $arr ) || Helper::isEmptyStr( $path ) ) {
                        return $arr;
                }

                if ( !Helper::contains( $path, '/' ) ) {
                        return isset( $arr[ $path ] ) ? $arr[ $path ] : "";
                }

                $parts = Helper::strToArr( $path, '/' );

                $data = $arr;

                foreach ( $parts as $part ) {

                        if ( isset( $data[ $part ] ) ) {
                                $data = $data[ $part ];
                        } else {
                                $data = null;
                                break;
                        }
                }

                return $data;
        }

        
        public static function safeArrayCombine( $keys = [], $values = [] ) {

                if ( !Helper::isNonEmptyArray( $keys ) || !Helper::isNonEmptyArray( $values ) ) {
                        return [];
                }

                $keySize = count( $keys );

                $valueSize = count( $values );

                if ( $keySize < $valueSize ) {
                        $values = array_slice( $values, 0, $keySize );
                }
                if ( $keySize > $valueSize ) {
                        $values = array_pad( $values, $keySize, '' );
                }

                return \array_combine( $keys, $values );
        }

        public static function updateNestedArray( &$array = [], $path = '', $value = '' ) {

                if ( !is_array( $array ) ) {
                        return;
                }

                if ( !Helper::contains( $path, '/' ) ) {
                        $array[ $path ] = $value;
                        return;
                }

                $keys    = explode( '/', $path );
                $current = &$array;

                foreach ( $keys as $key ) {
                        if ( !isset( $current[ $key ] ) ) {
                                $current[ $key ] = [];
                        }
                        $current = &$current[ $key ];
                }

                $current = $value;
        }
}
