<?php



namespace WpieApp\Core\Helpers;

use WP_Error;

defined( 'WPIE__FILE__' ) || exit;


trait File {

        
        public static function getFileExt( $file = "" ) {

                if ( !Helper::isNonEmptyStr( $file ) || strpos( $file, "." ) === false ) {
                        return "";
                }

                $info = Helper::strToArr( $file, "." );

                return strtolower( end( $info ) );
        }

        
        public static function isReadable( $file = "" ) {

                if ( !Helper::isNonEmptyStr( $file ) || !file_exists( $file ) ) {
                        /* translators: %s: File path */
                        return new WP_Error( 'wpieError', sprintf( __( '%s File Not Exist', 'wp-import-export' ), $file ) );
                }

                if ( !Helper::hasDirPermission( $file ) ) {
                        /* translators: %s: File path */
                        return new WP_Error( 'wpieError', sprintf( __( '%s File Access Denied', 'wp-import-export' ), $file ) );
                }

                if ( !is_readable( $file ) ) {
                        /* translators: %s: File path */
                        return new WP_Error( 'wpieError', sprintf( __( '%s File is not readable', 'wp-import-export' ), $file ) );
                }

                if ( filesize( $file ) === 0 ) {
                        /* translators: %s: File path */
                        return new WP_Error( 'wpieError', sprintf( __( '%s File is Empty', 'wp-import-export' ), $file ) );
                }

                return true;
        }

        
        public static function fOpenReadOnly( $file = "" ) {

                $isReadable = self::isReadable( $file );

                if ( \is_wp_error( $isReadable ) ) {

                        return $isReadable;
                }

                $fp = fopen( $file, "r" );

                if ( $fp === false ) {
                        /* translators: %s: File path */
                        return new WP_Error( 'wpieError', sprintf( __( 'Unable to Open FIle %s', 'wp-import-export' ), $file ) );
                }

                return $fp;
        }

        
        public static function fOpen( $file = "", $mode = "w" ) {

                $mode = Helper::sanitizeKey( $mode );

                if ( $mode === "r" ) {
                        return self::fOpenReadOnly( $file );
                }

                if ( !Helper::isNonEmptyStr( $file ) ) {
                        /* translators: %s: File path */
                        return new WP_Error( 'wpieError', sprintf( __( '%s File Name is empty', 'wp-import-export' ), $file ) );
                }

                $dir = \pathinfo( $file, PATHINFO_DIRNAME );

                if ( !is_dir( $dir ) ) {
                        return new WP_Error( 'wpieError', __( 'Directory is not readable', 'wp-import-export' ) );
                }

                if ( !Helper::hasDirPermission( $file ) ) {
                        return new WP_Error( 'wpieError', __( 'File Access Denied', 'wp-import-export' ) );
                }

                $fp = @fopen( $file, $mode );

                if ( $fp === false ) {
                        /* translators: %s: File path */
                        return new WP_Error( 'wpieError', sprintf( __( 'Unable to Open File %s', 'wp-import-export' ), $file ) );
                }

                return $fp;
        }

        
        public static function deleteFile( $files = [] ) {

                if ( Helper::isNonEmptyStr( $files ) ) {
                        $files = [ $files ];
                }

                if ( !Helper::isNonEmptyArray( $files ) ) {
                        return false;
                }

                foreach ( $files as $file ) {

                        if ( !Helper::hasDirPermission( $file ) ) {
                                continue;
                        }

                        if ( !file_exists( $file ) ) {
                                continue;
                        }

                        \wp_delete_file( $file );
                }

                return true;
        }

        
        public function isXmlFile( $file = "" ) {

                $fp = Helper::fOpenReadOnly( $file );

                if ( is_wp_error( $fp ) ) {
                        return $fp;
                }

                $data = fread( $fp, 20 );

                fclose( $fp );

                $data = preg_replace( '/[^a-zA-Z\?\<]/', '', $data );

                if ( Helper::strStartsWith( "<?xml", $data ) ) {
                        unset( $data, $fp );
                        return true;
                }

                unset( $data, $fp );
                /* translators: %s: File path */
                return new WP_Error( 'wpieError', sprintf( __( '%s Invalid XML File to read', 'wp-import-export' ), $file ) );
        }

        public static function convertBytes2Hr( $bytes = 0 ) {

                $sizes  = [ 'B', 'KB', 'MB', 'GB', 'TB', 'PB', 'EB', 'ZB', 'YB' ];
                $factor = $bytes > 0 ? floor( (log( $bytes ) / log( 1024 ) ) ) : 0;

                $size = $bytes / pow( 1024, $factor );
                $size = sprintf( "%.2f", $size ); // Limit to 2 decimal places

                return $size . " " . $sizes[ $factor ];
        }
}
