<?php



namespace WpieApp\Extensions\Export\Acf\Controller\Items\Base\Fields;

use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Base\Fields\InterfaceField;

defined( 'WPIE__FILE__' ) || exit;


abstract class Acf implements InterfaceField {

        
        const FIELD_TYPE = "acf";

        
        public static function getFieldGroupArg() {
                
        }

        
        public static function getLocationFilters() {
                
        }

        
        public static function get() {

                if (  !function_exists( '\acf_get_field_groups' ) || !function_exists( '\acf_get_fields' ) ) {
                        return [];
                }

                $groups = self::getFieldGroups();

                if ( !Helper::isNonEmptyArray( $groups ) ) {
                        return;
                }

                $acfFields = [];

                $priority = 28.001;

                foreach ( $groups as $group ) {

                        $key = isset( $group[ 'key' ] ) ? $group[ 'key' ] : (isset( $group[ 'ID' ] ) ? $group[ 'ID' ] : "");

                        $fields = self::getFields( $group );

                        if ( !Helper::isNonEmptyArray( $fields ) ) {
                                continue;
                        }

                        $title = isset( $group[ 'title' ] ) ? $group[ 'title' ] : "";

                        $acfFields[ 'acf-' . $key ] = [
                                "title"      => \esc_html__( "ACF", 'wp-import-export' ) . " - " . $title,
                                "priority"   => $priority,
                                "isFiltered" => false,
                                "pro"        => true,
                                "data"       => $fields
                        ];

                        $priority = $priority + 0.001;
                }

                
                return \apply_filters( 'Wpie/Export/Fields/Acf', $acfFields, Settings::getContentType() );
        }

        
        public static function getFieldGroups() {

                self::addRemoveLocationFilters();

                $groups = \acf_get_field_groups( static::getFieldGroupArg() );

                self::addRemoveLocationFilters( "remove" );

                return $groups;
        }

        
        public static function addRemoveLocationFilters( $action = '' ) {

                $filters = static::getLocationFilters();

                if ( !Helper::isNonEmptyArray( $filters ) ) {
                        return;
                }

                $fn = ("remove" === $action ? "remove_filter" : "add_filter");

                foreach ( $filters as $filter ) {
                        $fn( "acf/location/rule_match/" . $filter, '__return_true', 99999 );
                }
        }

        
        public static function getFields( $group = [] ) {

                $fields = \acf_get_fields( $group );

                if ( !Helper::isNonEmptyArray( $fields ) ) {
                        return [];
                }

                $groupTitle = isset( $group[ 'title' ] ) ? $group[ 'title' ] : "";

                $data = [];

                foreach ( $fields as $field ) {

                        $type = isset( $field[ 'type' ] ) ? $field[ 'type' ] : "";

                        if ( in_array( $type, [ 'acfe_button', 'acfe_hidden', 'acfe_recaptcha', 'accordion', 'message', 'tab', 'acfe_column', 'acfe_dynamic_render' ] ) ) {
                                continue;
                        }

                        $key = isset( $field[ 'key' ] ) ? $field[ 'key' ] : "";

                        $name = isset( $field[ 'name' ] ) ? $field[ 'name' ] : "";

                        $label = isset( $field[ 'label' ] ) ? $field[ 'label' ] : "";

                        $data[] = [
                                'label'   => $groupTitle . ' => ' . $label,
                                'type'    => self::FIELD_TYPE,
                                'element' => $type,
                                'key'     => $key,
                                'prefix'  => isset( $field[ 'prefix' ] ) ? $field[ 'prefix' ] : "",
                                'name'    => $name,
                        ];
                }

                return $data;
        }
}
