<?php



namespace WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\DataCenters;

use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Item extends Base {

        
        private static $items = [];

        
        private static $orderId = 0;

        
        public static function get( $element = "" ) {

                self::setItems();

                if ( 'total_items' === $element ) {
                        return DataCenter::getItem()->get_item_count();
                }

                if ( 'total_different_items' === $element ) {
                        return count( self::$items );
                }


                return self::getItems( $element );
        }

        
        private static function getItems( $element = "" ) {

                if ( !Helper::isNonEmptyArray( self::$items ) ) {
                        return '';
                }

                $data = [];

                foreach ( self::$items as $item ) {

                        $productId = $item->get_product_id();

                        $variationId = $item->get_variation_id();

                        switch ( $element ) {

                                case 'product_id':
                                        $data[] = $productId;
                                        break;

                                case 'variation_id':
                                        $data[] = $variationId;
                                        break;

                                case 'product_sku':
                                        $id      = absint( $variationId ) > 0 ? $variationId : $productId;
                                        $data[]  = \get_post_meta( $id, '_sku', true );
                                        break;
                                case 'product_title':
                                        $data[]  = $item->get_name();
                                        break;
                                case 'original_product_title':
                                        $data[]  = \get_the_title( $productId );
                                        break;
                                case 'variation_attributes':
                                        $product = $variationId ? $item->get_product() : '';
                                        $data[]  = ($variationId && is_callable( [ $product, 'get_variation_attributes' ] )) ? $product->get_variation_attributes() : '';
                                        break;
                                case 'quantity':
                                        $data[]  = $item->get_quantity();
                                        break;
                                case 'subtotal':
                                        $data[]  = $item->get_subtotal();
                                        break;
                                case 'total':
                                        $data[]  = $item->get_total();
                                        break;
                                case 'subtotal_tax':
                                        $tax     = $item->get_taxes();
                                        $data[]  = is_array( $tax ) && isset( $tax[ 'subtotal' ] ) ? $tax[ 'subtotal' ] : '';
                                        break;
                                case 'total_tax':
                                        $tax     = $item->get_taxes();
                                        $data[]  = is_array( $tax ) && isset( $tax[ 'total' ] ) ? $tax[ 'total' ] : '';
                                        break;
                                case 'taxes':
                                        $data[]  = $item->get_taxes();
                                        break;
                                case 'meta':
                                        $data[]  = $item->get_formatted_meta_data( '_', true );
                                        break;
                        }
                }

                return $data;
        }

        
        private static function setItems() {

                if ( self::$orderId === DataCenter::getId() ) {
                        return;
                }

                self::$orderId = DataCenter::getId();

                self::$items = DataCenter::getItem()->get_items();
        }
}
