<?php



namespace WpieApp\Extensions\Export\WooCommerce\Controller\Items\Order\Standard\Query;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Base\Engine\Base;
use Automattic\WooCommerce\Internal\DataStores\Orders\OrdersTableDataStore;

defined( 'WPIE__FILE__' ) || exit;


class Order {

        
        private static $field = 'id';

        
        private static $alias = '';

        
        private static $args = [];

        
        public static function query( $args = [] ) {

                self::$args = $args;

                $data = self::run();

                return (isset( $args[ 'count' ] ) && $args[ 'count' ] ) ? array_shift( $data ) : $data;
        }

        
        private static function run() {

                $table      = self::getTable();
                $tableAlias = self::getTableAlias();
                $fields     = self::getField();

                $join  = self::getJoin();
                $where = self::getWhere();

                $groupby = self::getGroupBy();
                $orderby = self::getOrderBy();

                $limits = self::getLimit();

                $sql = "SELECT $fields FROM $table as $tableAlias $join WHERE $where $groupby $orderby $limits";
                
                return \array_map( 'absint', DB::wpdb()->get_col( $sql ) );
        }

        
        private static function getLimit() {

                $limit  = isset( self::$args[ 'limit' ] ) ? absint( self::$args[ 'limit' ] ) : false;
                $offset = isset( self::$args[ 'offset' ] ) ? absint( self::$args[ 'offset' ] ) : 0;

                // Bool false indicates no limit was specified;
                if ( false === $limit || $limit <= 0 ) {
                        return '';
                }

                return 'LIMIT ' . $offset . ', ' . $limit;
        }

        
        private static function getField() {

                $field = self::getTableAlias() . '.' . self::$field;

                if ( isset( self::$args[ 'count' ] ) && self::$args[ 'count' ] ) {
                        return 'COUNT(DISTINCT ' . $field . ') as total';
                }

                return $field;
        }

        
        private static function getWhere() {

                $where = isset( self::$args[ 'where' ] ) ? self::$args[ 'where' ] : '';

                $default = ' ' . self::getTableAlias() . '.`type` = "shop_order" AND ' . self::getTableAlias() . '.`status` != "auto-draft" ';

                return Helper::isNonEmptyStr( $where ) ? $default . ' ' . $where : $default;
        }

        
        private static function getJoin() {

                if ( !isset( self::$args[ 'join' ] ) || !Helper::isNonEmptyStr( self::$args[ 'join' ] ) ) {
                        return '';
                }

                return self::$args[ 'join' ];
        }

        
        private static function getOrderBy() {

                return 'ORDER BY ' . self::getTableAlias() . '.' . self::$field . ' ASC';
        }

        
        private static function getGroupBy() {

                if ( !isset( self::$args[ 'groupby' ] ) || !Helper::isNonEmptyStr( self::$args[ 'groupby' ] ) ) {
                        return '';
                }

                return 'GROUP BY ' . self::getTableAlias() . '.' . self::$field;
        }

        
        public static function getTableAlias() {

                if ( !Helper::isNonEmptyStr( self::$alias ) ) {
                        self::$alias = Helper::randStr( 'order' );
                }

                return self::$alias;
        }

        
        public static function getTable() {

                return OrdersTableDataStore::get_orders_table_name();
        }
}
