<?php



namespace WpieApp\Extensions\Export\WooCommerce\Controller\Items\Product\Fields;

use WpieApp\Core\Utils\DB;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Items\Base\Fields\InterfaceField;
use WpieApp\Modules\Export\Controller\Items\Post\Fields\Meta as PostMeta;

defined( 'WPIE__FILE__' ) || exit;


class Attribute implements InterfaceField {

        
        const FIELD_TYPE = "attribute";

        
        public static function get() {

                $fields = [
                        "title"    => esc_html__( "Product Attributes", 'wp-import-export' ),
                        "priority" => 26,
                        "data"     => self::getFields()
                ];

                
                return \apply_filters( 'Wpie/Export/Product/Fields/Attributes', $fields );
        }

        
        private static function getFields() {

                $fields = self::getTaxonomyAttr();

                $fields = array_replace( self::getMetaAttr(), $fields );

                if ( !Helper::isNonEmptyArray( $fields ) ) {
                        return [];
                }

                $attrFields = [
                        [
                                'label'      => 'All Attributes',
                                'type'       => PostMeta::FIELD_TYPE,
                                'element'    => '_product_attributes',
                                'isFiltered' => false
                        ],
                        [
                                'label'      => 'Default Attributes',
                                'type'       => PostMeta::FIELD_TYPE,
                                'element'    => '_default_attributes',
                                'isFiltered' => false
                        ],
                ];

                foreach ( $fields as $key => $data ) {

                        $label = isset( $data[ 'label' ] ) ? $data[ 'label' ] : "";

                        $source = isset( $data[ 'source' ] ) ? $data[ 'source' ] : "";

                        $attrFields = array_merge( $attrFields, self::getAttributeFields( $key, $label, $source ) );
                }

                return $attrFields;
        }

        
        private static function getTaxonomyAttr() {

                global $wp_taxonomies;

                $taxonomy = [];

                if ( Helper::isEmpty( $wp_taxonomies ) ) {
                        return $taxonomy;
                }

                foreach ( $wp_taxonomies as $key => $tax ) {

                        if ( strpos( $key, "pa_" ) !== 0 || !in_array( "product", $tax->object_type ) ) {
                                continue;
                        }

                        $taxonomy[ $key ] = [
                                "label"  => (( isset( $tax->labels ) && isset( $tax->labels->singular_name ) ) ? $tax->labels->singular_name : $key),
                                "source" => "taxonomy",
                        ];
                }

                return $taxonomy;
        }

        
        private static function getMetaAttr() {


                
                $limit = \apply_filters( 'Wpie/Export/Product/Fields/Attributes/Limit', 500 );

                $attrKeys = DB::wpdb()->get_col(
                        DB::wpdb()->prepare(
                                "SELECT DISTINCT postmeta.meta_key
				FROM " . DB::wpdb()->postmeta . " AS postmeta
				LEFT JOIN " . DB::wpdb()->posts . " AS posts ON ( posts.ID = postmeta.post_id )
				WHERE posts.post_type IN ( 'product' , 'product_variation' )
					AND postmeta.meta_key LIKE 'attribute_%'
					AND postmeta.meta_key NOT LIKE 'attribute_pa_%'
                                        AND postmeta.meta_value != ''
                                ORDER BY postmeta.meta_key
				LIMIT %d",
                                $limit
                        )
                );

                $attrFields = [];

                if ( Helper::isEmpty( $attrKeys ) ) {
                        return $attrFields;
                }

                foreach ( $attrKeys as $attribute ) {

                        $key = preg_replace( '%^attribute_%', '', $attribute );

                        $attrFields[ $key ] = [
                                "label"  => $key,
                                "source" => "meta",
                        ];
                }


                return $attrFields;
        }

        
        private static function getAttributeFields( $element = "", $label = "", $source = "taxonomy" ) {

                return [
                        [
                                'label'      => 'Attribute Name (' . $label . ')',
                                'type'       => 'text',
                                'data'       => $label,
                                'element'    => $element,
                                'isFiltered' => false
                        ],
                        [
                                'label'      => 'Attribute Value (' . $label . ')',
                                'type'       => self::FIELD_TYPE,
                                'element'    => $element,
                                'source'     => $source,
                                'comparison' => [ 'string' ],
                                'isFiltered' => ($source === "taxonomy" ? true : false),
                                'dataType'   => 'value'
                        ],
                        [
                                'label'      => 'Attribute Slug (' . $label . ')',
                                'type'       => 'text',
                                'data'       => Helper::strStartsWith( 'pa_', $element ) ? \mb_substr( $element, 3 ) : $element,
                                'element'    => $element,
                                'isFiltered' => false
                        ],
                        [
                                'label'      => 'Attribute In Variations (' . $label . ')',
                                'type'       => self::FIELD_TYPE,
                                'element'    => $element,
                                'dataType'   => 'inVariations',
                                'isFiltered' => false
                        ],
                        [
                                'label'      => 'Attribute Is Visible (' . $label . ')',
                                'type'       => self::FIELD_TYPE,
                                'element'    => $element,
                                'dataType'   => 'isVisible',
                                'isFiltered' => false
                        ],
                        [
                                'label'      => 'Attribute Is Taxonomy (' . $label . ')',
                                'type'       => 'text',
                                'data'       => ($source === "taxonomy" ? "Yes" : "No"),
                                'element'    => $element,
                                'isFiltered' => false
                        ],
                        [
                                'label'      => 'Attribute Position (' . $label . ')',
                                'type'       => self::FIELD_TYPE,
                                'element'    => $element,
                                'dataType'   => 'position',
                                'isFiltered' => false
                        ]
                ];
        }
}
