<?php



namespace WpieApp\Extensions\Import\Acf\Controller\Items\Base\Fields;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;

defined( 'WPIE__FILE__' ) || exit;


class Choice extends Base {

        
        protected static $fieldTypes = [ 'button_group', 'checkbox', 'acfe_countries', 'acfe_currencies', 'acfe_image_selector', 'acfe_languages', 'radio', 'select', 'true_false' ];

        
        public static function getField( $field = [], $order = 5 ) {

                $type = isset( $field[ 'type' ] ) ? $field[ 'type' ] : "";

                if ( !in_array( $type, [ 'select', 'checkbox', 'acfe_countries', 'acfe_currencies', 'acfe_languages' ] ) ) {
                        return parent::getField( $field, $order );
                }

                $key = isset( $field[ 'key' ] ) ? $field[ 'key' ] : "";

                $label = isset( $field[ 'label' ] ) ? $field[ 'label' ] : "";

                return [
                        "title"    => $label,
                        "desc"     => $label,
                        "order"    => $order,
                        "isActive" => 5 === $order,
                        "fields"   => [
                                "field" => [
                                        "order"      => 5,
                                        "label"      => $label,
                                        "sub-fields" => [
                                                "field"     => [
                                                        "description" => $label,
                                                        "name"        => "fields/acf/" . $key . "/data",
                                                        "type"        => "textarea",
                                                        "hint"        => static::getHints( $type )
                                                ],
                                                "separator" => [
                                                        "description" => __( 'Multiple value Separator', 'wp-import-export' ),
                                                        "name"        => "fields/acf/" . $key . "/separator",
                                                        "type"        => "textarea",
                                                        "hint"        => [
                                                                [ 'text' => __( 'Optional', 'wp-import-export' ) ],
                                                                [ 'text' => __( 'Default : ||', 'wp-import-export' ) ],
                                                                [ 'text' => __( 'Multiple values are separated by', 'wp-import-export' ) ],
                                                        ]
                                                ]
                                        ],
                                ],
                        ]
                ];
        }

        
        protected static function getHints( $type = '' ) {

                $hints = parent::getHints( $type );

                switch ( $type ) {

                        case 'true_false':
                                $hints[] = [ 'text' => __( 'yes, no, true, false, 0, 1 values are supported', 'wp-import-export' ) ];
                                break;

                        case 'radio':
                        case 'button_group':
                        case 'acfe_image_selector':
                                $hints[] = [ 'text' => __( 'Please insert label or value', 'wp-import-export' ) ];
                                break;

                        case 'select':
                        case 'checkbox':
                        case 'acfe_countries':
                        case 'acfe_currencies':
                        case 'acfe_languages':
                                $hints[] = [ 'text' => __( 'Please insert label or value', 'wp-import-export' ) ];
                                $hints[] = [ 'text' => __( 'multiple value supported', 'wp-import-export' ) ];
                                break;
                }

                return $hints;
        }
}
