<?php



namespace WpieApp\Extensions\Import\AllInOneSeo\Controller\Items\Base\Engines;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Post\DataCenter;
use WpieApp\Extensions\Import\AllInOneSeo\Controller\Items\Base\Fields\Advanced\Priority;
use WpieApp\Extensions\Import\AllInOneSeo\Controller\Items\Base\Fields\Advanced\Frequency;

defined( 'WPIE__FILE__' ) || exit;


class Advanced {

        
        public static function get() {

                $data = [];

                if ( DataCenter::canUpdate( 'allinoneseo/advanced/robots_default' ) ) {
                        $data[ "default" ] = Helper::detectBoolVal( DataCenter::get( "allinoneseo/advanced/robots_default/data" ) ) !== false;
                }

                if ( DataCenter::canUpdate( 'allinoneseo/advanced/canonical_url' ) ) {
                        $data[ "canonicalUrl" ] = DataCenter::get( "allinoneseo/advanced/canonical_url/data" );
                }

                if ( DataCenter::canUpdate( 'allinoneseo/advanced/priority' ) ) {

                        $priority = DataCenter::get( "allinoneseo/advanced/priority/data" );

                        $data[ "priority" ] = Helper::autoFixStr( $priority, Priority::getPriority() );
                }

                if ( DataCenter::canUpdate( 'allinoneseo/advanced/frequency' ) ) {

                        $frequency = DataCenter::get( "allinoneseo/advanced/frequency/data" );

                        $data[ "frequency" ] = Helper::autoFixStr( $frequency, Frequency::getFrequency() );
                }

                if ( DataCenter::canUpdate( 'allinoneseo/advanced/keywords' ) ) {

                        $data[ "keywords" ] = self::getKeywords();
                }

                return \array_merge( $data, self::getRobots(), self::getRobotsAdv() );
        }

        
        public static function getKeywords() {

                $separator = DataCenter::get( "allinoneseo/advanced/keywords/separator" );

                $separator = Helper::isNonEmptyStr( $separator ) ? $separator : ",";

                $keywords = Helper::strToArr( DataCenter::get( "allinoneseo/advanced/keywords/data" ), $separator );

                if ( !Helper::isNonEmptyArray( $keywords ) ) {
                        return '';
                }

                $data = [];

                foreach ( $keywords as $keyword ) {

                        $data[] = [ "label" => $keyword, "value" => $keyword ];
                }

                return Helper::jsonEncode( $data );
        }

        
        private static function getRobots() {

                $fields = [ "noindex", "nofollow", "noarchive", "notranslate", "noimageindex", "nosnippet", "noodp" ];

                $data = [];

                foreach ( $fields as $field ) {

                        if ( !DataCenter::canUpdate( 'allinoneseo/advanced/' . $field ) ) {
                                continue;
                        }

                        $robots = DataCenter::get( "allinoneseo/advanced/" . $field . "/data" );

                        $data[ $field ] = Helper::detectBoolVal( $robots ) !== false;
                }

                return $data;
        }

        
        private static function getRobotsAdv() {

                $data = [];

                if ( DataCenter::canUpdate( 'allinoneseo/advanced/max_snippet' ) ) {
                        $data[ "maxSnippet" ] = DataCenter::get( "allinoneseo/advanced/max_snippet/data" );
                }

                if ( DataCenter::canUpdate( 'allinoneseo/advanced/max_video_preview' ) ) {
                        $data[ "maxVideoPreview" ] = DataCenter::get( "allinoneseo/advanced/max_video_preview/data" );
                }

                if ( DataCenter::canUpdate( 'allinoneseo/advanced/max_image_preview' ) ) {

                        $robots = DataCenter::get( "allinoneseo/advanced/max_image_preview/data" );

                        $data[ "maxImagePreview" ] = Helper::autoFixStr( $robots, [ "large", "standard", "none" ] );
                }

                return $data;
        }
}
