<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Attribute\Engines;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;
use WpieApp\Modules\Import\Controller\Items\Term\DataCenter;
use WpieApp\Modules\Import\Controller\Items\Term\Settings;

defined( 'WPIE__FILE__' ) || exit;


class Attribute {

        
        private static $cache = [];

        
        private static $attributeTaxonomies = null;

        
        public static function update() {
                self::setTaxonomy();
        }

        
        public static function setTaxonomy() {

                Settings::setOption( 'taxonomy/name', self::getTaxonomy() );
        }

        
        public static function getTaxonomy() {

                $arg = [];

                if ( DataCenter::canUpdate( 'attribute/name' ) ) {

                        $arg[ 'name' ] = DataCenter::get( 'attribute/name/data' );
                }
                if ( DataCenter::canUpdate( 'attribute/slug' ) ) {

                        $arg[ 'slug' ] = DataCenter::get( 'attribute/slug/data' );
                }
                if ( DataCenter::canUpdate( 'attribute/enable_archive' ) ) {

                        $arg[ 'has_archive' ] = Helper::detectBoolVal( DataCenter::get( 'attribute/enable_archive/data' ) );
                }
                if ( DataCenter::canUpdate( 'attribute/order_by' ) ) {

                        $arg[ 'order_by' ] = DataCenter::get( 'attribute/order_by/data' );
                }

                if ( (!isset( $arg[ 'name' ] ) || !Helper::isNonEmptyStr( $arg[ 'name' ] )) && (!isset( $arg[ 'slug' ] ) || !Helper::isNonEmptyStr( $arg[ 'slug' ] )) ) {
                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . __( 'Attribute name and slug are missing', 'wp-import-export' ) );
                        return '';
                }

                $id = self::get( $arg );

                if ( $id < 1 ) {
                        return '';
                }

                $attribute = \wc_get_attribute( $id );

                if ( $attribute && isset( $attribute->slug ) ) {
                        return $attribute->slug;
                }

                return '';
        }

        
        public static function get( $arg = [] ) {

                if ( !Helper::isNonEmptyArray( $arg ) ) {
                        return 0;
                }

                $id = self::getCache( $arg );

                if ( $id < 1 ) {
                        $id = self::search( $arg );
                }
                if ( $id < 1 ) {
                        $id = self::register( $arg );
                }

                return $id;
        }

        
        public static function search( $arg = [] ) {

                if ( !Helper::isNonEmptyArray( $arg ) ) {
                        return 0;
                }

                $name = isset( $arg[ 'name' ] ) ? $arg[ 'name' ] : '';

                $slug = isset( $arg[ 'slug' ] ) ? $arg[ 'slug' ] : '';

                if ( !Helper::isNonEmptyStr( $name ) && !Helper::isNonEmptyStr( $slug ) ) {
                        return 0;
                }

                if ( !Helper::isNonEmptyArray( self::getAttributeTaxonomies() ) ) {
                        return 0;
                }

                $attributeId = 0;

                foreach ( self::getAttributeTaxonomies() as $attribute ) {

                        $attributeName = isset( $attribute->attribute_label ) ? $attribute->attribute_label : '';

                        $id = isset( $attribute->attribute_id ) ? $attribute->attribute_id : 0;

                        if ( Helper::isNonEmptyStr( $name ) && $attributeName === $name ) {
                                $attributeId                     = $id;
                                self::$cache[ 'name' ] [ $name ] = $id;
                                break;
                        }

                        $attributeslug = isset( $attribute->attribute_name ) ? $attribute->attribute_name : '';

                        if ( Helper::isNonEmptyStr( $slug ) && $attributeslug === $slug ) {
                                $attributeId                     = $id;
                                self::$cache[ 'slug' ] [ $slug ] = $id;
                                break;
                        }
                }

                return $attributeId;
        }

        
        public static function register( $arg = [] ) {

                if ( !Helper::isNonEmptyArray( $arg ) ) {
                        return 0;
                }

                $name = isset( $arg[ 'name' ] ) ? $arg[ 'name' ] : '';

                $slug = isset( $arg[ 'slug' ] ) ? $arg[ 'slug' ] : '';

                if ( !Helper::isNonEmptyStr( $name ) || !Helper::isNonEmptyStr( $slug ) ) {
                        return 0;
                }

                if ( \taxonomy_exists( \wc_attribute_taxonomy_name( $name ) ) ) {
                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . __( 'Taxonomy already exists', 'wp-import-export' ) );
                        return 0;
                }

                // If the attribute does not exist, create it.
                $attributeId = \wc_create_attribute(
                        [
                                'name'         => $name,
                                'slug'         => $slug,
                                'type'         => 'select',
                                'order_by'     => isset( $arg[ 'order_by' ] ) && Helper::isNonEmptyStr( $arg[ 'order_by' ] ) ? $arg[ 'order_by' ] : 'menu_order',
                                'has_archives' => isset( $arg[ 'has_archives' ] ) && is_bool( $arg[ 'has_archives' ] ) ? $arg[ 'has_archives' ] : false
                        ]
                );

                self::$attributeTaxonomies = null;

                if ( \is_wp_error( $attributeId ) ) {
                        Logger::error( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . $attributeId->get_error_message() );
                        return 0;
                }
                /* translators: %s: Attribute name */
                Logger::log( sprintf( __( 'New Attribute %s created', 'wp-import-export' ), $name ) );

                $taxonomy = self::registerTaxonomy( $name );

                if ( \is_wp_error( $taxonomy ) ) {
                        Logger::error( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . $taxonomy->get_error_message() );
                        return 0;
                }

                self::updateBaseAttributes();

                return $attributeId;
        }

        
        private static function registerTaxonomy( $name ) {

                // Register as taxonomy while importing.
                $taxonomyName = \wc_attribute_taxonomy_name( $name );

                if ( \taxonomy_exists( $taxonomyName ) ) {
                        return true;
                }

                return \register_taxonomy(
                        $taxonomyName,
                        apply_filters( 'woocommerce_taxonomy_objects_' . $taxonomyName, [ 'product' ] ),
                        apply_filters(
                                'woocommerce_taxonomy_args_' . $taxonomyName,
                                [
                                        'labels'       => [
                                                'name' => $name,
                                        ],
                                        'hierarchical' => true,
                                        'show_ui'      => false,
                                        'query_var'    => true,
                                        'rewrite'      => false,
                                ]
                        )
                );
        }

        
        private static function updateBaseAttributes() {

                global $wc_product_attributes;

                // Set product attributes global.
                $wc_product_attributes = [];

                foreach ( self::getAttributeTaxonomies() as $taxonomy ) {
                        $wc_product_attributes[ \wc_attribute_taxonomy_name( $taxonomy->attribute_name ) ] = $taxonomy;
                }
        }

        
        private static function getAttributeTaxonomies() {

                if ( is_null( self::$attributeTaxonomies ) ) {
                        self::$attributeTaxonomies = \wc_get_attribute_taxonomies();
                }

                return self::$attributeTaxonomies;
        }

        
        private static function getCache( $arg = [] ) {

                if ( !Helper::isNonEmptyArray( $arg ) ) {
                        return 0;
                }

                $name = isset( $arg[ 'name' ] ) ? $arg[ 'name' ] : '';

                $slug = isset( $arg[ 'slug' ] ) ? $arg[ 'slug' ] : '';

                if ( !isset( self::$cache[ 'name' ] ) ) {
                        self::$cache[ 'name' ] = [];
                }
                if ( Helper::isNonEmptyStr( $name ) && isset( self::$cache[ 'name' ][ $name ] ) ) {
                        return self::$cache[ 'name' ] [ $name ];
                }

                if ( !isset( self::$cache[ 'slug' ] ) ) {
                        self::$cache[ 'slug' ] = [];
                }

                if ( Helper::isNonEmptyStr( $slug ) && isset( self::$cache[ 'slug' ][ $slug ] ) ) {
                        return self::$cache[ 'slug' ] [ $slug ];
                }

                return 0;
        }
}
