<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Engines;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Post\DataCenter;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Engines\Attributes\Attribute;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Engines\Attributes\VariationAttributes;

defined( 'WPIE__FILE__' ) || exit;


class Attributes {

        
        public static function get() {

                $data = [];

                $attributes = self::getAttributes();

                if ( Helper::isNonEmptyArray( $attributes ) ) {
                        $data[ 'attributes' ] = $attributes;
                }

                $defaultAttributes = self::getDefaultAttributes();

                if ( Helper::isNonEmptyArray( $defaultAttributes ) ) {
                        $data[ 'default_attributes' ] = $defaultAttributes;
                }

                unset( $attributes, $defaultAttributes );

                return $data;
        }

        
        private static function getDefaultAttributes() {

                if ( !DataCenter::canUpdate( "attributes/default" ) || !Product::getProduct()->is_type( 'variable' ) ) {
                        return [];
                }

                $attributes = DataCenter::get( "attributes/default/data" );

                if ( !Helper::isNonEmptyStr( $attributes ) ) {
                        return [];
                }

                $data = Helper::jsonDecode( $attributes, true );

                if ( \is_wp_error( $data ) ) {
                        return [];
                }

                return $data;
        }

        
        private static function getAttributes() {

                if ( !DataCenter::canUpdate( "attributes/attribute" ) ) {
                        return [];
                }

                return Product::getProduct()->is_type( 'variation' ) ? VariationAttributes::get() : Attribute::get();
        }

        
        public static function getVariationRawAttributes() {

                $attributes = VariationAttributes::getAttrList();

                if ( !Helper::isNonEmptyArray( $attributes ) ) {
                        return [];
                }
                $variationAttr = [];

                foreach ( $attributes as $key => $value ) {
                        $variationAttr[ 'attribute_' . $key ] = $value;
                }

                return $variationAttr;
        }
}
