<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Engines\Attributes;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Term\Search;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;

defined( 'WPIE__FILE__' ) || exit;


class Term {

        
        private static $cache = [];

        
        public static function get( $terms = [], $taxonomy = '' ) {

                if ( !Helper::isNonEmptyArray( $terms ) || !Helper::isNonEmptyStr( $taxonomy ) || !taxonomy_exists( $taxonomy ) ) {
                        return [];
                }

                $data = [];

                foreach ( $terms as $term ) {

                        if ( !Helper::isNonEmptyStr( $term ) ) {
                                continue;
                        }

                        if ( isset( self::$cache[ $taxonomy ] ) ) {
                                self::$cache[ $taxonomy ] = [];
                        }

                        $termId = 0;

                        if ( isset( self::$cache[ $taxonomy ][ $term ] ) ) {
                                $termId = self::$cache[ $taxonomy ][ $term ];
                        }

                        if ( $termId < 1 ) {
                                $termId = Search::findTerm( [ 'name', 'slug' ], $term, $taxonomy );
                        }
                        if ( $termId < 1 ) {
                                $termId = self::add( $term, $taxonomy );
                        }
                        if ( $termId < 1 ) {
                                continue;
                        }

                        self::$cache[ $taxonomy ][ $term ] = $termId;

                        $data[] = $termId;
                }

                return $data;
        }

        
        private static function add( $termName = '', $taxonomy = '' ) {

                if ( !Helper::isNonEmptyStr( $termName ) ) {
                        return 0;
                }

                $term = \wp_insert_term( $termName, $taxonomy );

                if ( \is_wp_error( $term ) ) {

                        if ( $term->get_error_code() === 'term_exists' ) {
                                // When term exists, error data should contain existing term id.
                                return $term->get_error_data();
                        } else {

                                Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . $term->get_error_message() );
                                return 0;
                        }
                }


                return isset( $term[ 'term_id' ] ) ? $term[ 'term_id' ] : 0;
        }
}
