<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Engines\Attributes;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;
use WpieApp\Modules\Import\Controller\Items\Term\Search;

defined( 'WPIE__FILE__' ) || exit;


class VariationAttributes extends Base {

        
        public static function get() {

                $rawAttributes = self::getRawAttributes();

                if ( !Helper::isNonEmptyArray( $rawAttributes ) ) {
                        return [];
                }

                $parentAttributes = [];

                $attributes = self::getExistingAttributes();

                foreach ( $rawAttributes as $taxonomy => $data ) {

                        $attribute = parent::generate( $data );

                        $value = $attribute->is_taxonomy() ? $attribute->get_slugs() : \sanitize_title( $value );

                        $parentAttributes[ $taxonomy ] = $attribute;

                        $attributes[ \sanitize_title( $taxonomy ) ] = is_array( $value ) ? array_shift( $value ) : $value;
                }

                ParentAttributes::update( $parentAttributes );

                return $attributes;
        }

        
        public static function getAttrList() {

                $rawAttributes = self::getRawAttributes();

                if ( !Helper::isNonEmptyArray( $rawAttributes ) ) {
                        return [];
                }

                $attributes = [];

                foreach ( $rawAttributes as $taxonomy => $attribute ) {

                        $termData = isset( $attribute[ 'value' ] ) ? current( $attribute[ 'value' ] ) : "";

                        if ( isset( $attribute[ 'is_taxonomy' ] ) && \absint( $attribute[ 'is_taxonomy' ] ) === 1 ) {

                                $term = self::getTerm( $termData, $taxonomy );

                                if ( $term !== false && isset( $term->term_id ) ) {
                                        $termData = isset( $term->slug ) ? $term->slug : $termData;
                                }
                        }

                        $attributes[ $taxonomy ] = $termData;
                }

                return $attributes;
        }

        
        public static function getTerm( $value, $taxonomy ) {

                $term = Search::getTerm( 'name', $value, $taxonomy );

                if ( $term !== false && isset( $term->term_id ) ) {
                        return $term;
                }

                return Search::getTerm( 'slug', $value, $taxonomy );
        }
}
