<?php



namespace WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product;

use WC_Data_Store;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;
use WpieApp\Modules\Import\Controller\Items\Post\Engines\Standard;
use WpieApp\Modules\Import\Controller\Items\Post\Engines\Author;
use WpieApp\Modules\Import\Controller\Items\Post\DataCenter;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Engines\Meta;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Engines\Variable\Log;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Engines\Attributes;
use WpieApp\Extensions\Import\WooCommerce\Controller\Items\Product\Engines\Product;

defined( 'WPIE__FILE__' ) || exit;


class VariationsEngine {

        
        private static $isVariation = false;

        
        private static $parentId = 0;

        
        public static function update() {

                $parentId = Log::get( 'parent' );

                self::$parentId = $parentId;

                self::setVariation();
        }

        
        private static function setVariation() {

                if ( self::$parentId > 0 ) {
                        self::$isVariation = true;
                        return;
                }

                $type = Helper::autoFixStr( DataCenter::get( "type/product-type/data" ), [ 'variation' ], false );

                if ( 'variation' === $type ) {
                        self::$isVariation = true;
                        return;
                }

                self::$isVariation = false;
        }

        
        public static function isVariation() {
                return self::$isVariation;
        }

        
        public static function import() {

                $product = Product::getObject( 'variation', DataCenter::getId() );

                return Product::import( $product );
        }

        
        public static function preparePost() {

                $standard = Standard::get();
                $author   = Author::get();
                $data     = array_merge( $standard, $author );

                $data[ 'post_type' ] = 'product_variation';

                $data[ 'post_status' ] = 'publish';

                if ( self::$parentId > 0 ) {
                        $data[ 'post_parent' ] = self::$parentId;
                }

                return $data;
        }

        
        public static function updatePost() {

                Standard::relinkContent();

                Meta::import();
        }

        
        public static function parentHasChild() {

                if ( !self::$isVariation ) {
                        return true;
                }

                if ( self::$parentId < 1 ) {
                        return true;
                }

                $product = \wc_get_product( self::$parentId );

                if ( !is_a( $product, '\WC_Product_Variable' ) ) {
                        return true;
                }

                $children = $product->get_children();

                unset( $product );

                return Helper::isNonEmptyArray( $children );
        }

        
        public static function validateSearch( $id = 0 ) {

                if ( $id > 0 && !self::$isVariation ) {
                        self::$isVariation = ('product_variation' === \get_post_type( $id ));
                }

                if ( $id > 1 && $id === self::$parentId && self::$isVariation ) {
                        $id = 0;
                }

                if ( $id < 1 && self::$isVariation ) {
                        $id = self::searchByAttributes();
                }

                return $id;
        }

        
        private static function searchByAttributes() {

                if ( self::$parentId < 1 ) {
                        return 0;
                }

                $product = \wc_get_product( self::$parentId );

                if ( !is_a( $product, '\WC_Product_Variable' ) ) {
                        Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> : " . __( "Variable Product cannot be loaded", 'wp-import-export' ) );
                        return 0;
                }

                $attributes = Attributes::getVariationRawAttributes();

                $dataStore = WC_Data_Store::load( 'product' );

                $id = $dataStore->find_matching_product_variation( $product, $attributes );

                unset( $product, $attributes, $dataStore );

                return $id;
        }
}
