<?php



namespace WpieApp\Modules\Debug\View\Logs\SystemInfo;

use WpieApp\Core\Utils\DB;

defined( 'WPIE__FILE__' ) || exit;


class DatabaseTables {

        
        public static function get() {

                return [
                        "label" => __( 'Database Tables', 'wp-import-export' ),
                        "order" => 60,
                        "data"  => self::getTables()
                ];
        }

        
        private static function getTables() {

                // It is not possible to get the database name from some classes that replace wpdb (e.g., HyperDB)
                // and that is why this if condition is needed.
                if ( !defined( 'DB_NAME' ) ) {
                        return [];
                }

                $tables = [];

                $databaseTableInformation = DB::wpdb()->get_results(
                        DB::wpdb()->prepare(
                                "SELECT
					    table_name AS 'name',
						engine AS 'engine',
					    round( ( data_length / 1024 / 1024 ), 2 ) 'data',
					    round( ( index_length / 1024 / 1024 ), 2 ) 'index'
					FROM information_schema.TABLES
					WHERE table_schema = %s
					ORDER BY name ASC;",
                                DB_NAME
                        )
                );

                $siteTablesPrefix = DB::wpdb()->get_blog_prefix( \get_current_blog_id() );

                $globalTables = DB::wpdb()->tables( 'global', true );

                foreach ( $databaseTableInformation as $table ) {
                        // Only include tables matching the prefix of the current site, this is to prevent displaying all tables on a MS install not relating to the current.
                        if ( \is_multisite() && 0 !== strpos( $table->name, $siteTablesPrefix ) && !in_array( $table->name, $globalTables, true ) ) {
                                continue;
                        }

                        $label  = isset( $table->name ) ? $table->name : "";
                        $data   = isset( $table->data ) ? $table->data : "";
                        $index  = isset( $table->index ) ? $table->index : "";
                        $engine = isset( $table->engine ) ? $table->engine : "";

                        $tables[] = [
                                'label' => $label,
                                 /* translators: 1: Data In MB. 2: Index in MB. 3: Engine in MB. */
                                'data'  => sprintf( __( 'Data: %1$s MB + Index: %2$s MB + Engine %3$s', 'wp-import-export' ), $data, $index, $engine )
                        ];
                }

                return $tables;
        }

}
