<?php



namespace WpieApp\Modules\Export\Controller\Items\Comment;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Base\Engine\Base;

defined( 'WPIE__FILE__' ) || exit;


class Engine extends Base {

        
        protected static function getData() {

                
                \do_action( 'Wpie/Export/Comment/Start', Settings::getContentType() );

                $query = static::buildQuery();

                if ( !Helper::isNonEmptyArray( $query ) ) {
                        return false;
                }

                static::initFilter();
                self::addRemoveFilters();

                // Run query
                $data = \get_comments( $query );

                self::addRemoveFilters( 'remove' );

                if ( self::$action === "total" ) {
                        return Helper::toInt( $data );
                }

                // Clear memory
                unset( $query );

                return DataCenter::init( $data, self::$action );
        }

        
        private static function addRemoveFilters( $action = "add" ) {

                $fn = ($action === "remove" ? "remove_filter" : "add_filter");

                // Apply filter rules
                $fn( 'comments_clauses', [ __CLASS__, 'addWhereJoin' ] );

                $fn( 'comments_clauses', [ __CLASS__, 'setUniqueComments' ] );
        }

        
        private static function initFilter() {

                
                \do_action( 'Wpie/Export/Comment/Filter/Start', Settings::getContentType() );

                Filter::init();

                
                \do_action( 'Wpie/Export/Comment/Filter/Init', Settings::getContentType() );

                static::initBaseFilter();

                self::$where = Filter::getWhere();
                self::$join  = Filter::getJoin();
        }

        
        protected static function buildQuery() {

                $query = [
                        'orderby' => "comment_ID",
                        'order'   => 'ASC',
                        'fields'  => 'ids',
                ];
                
                 $preQuery = parent::buildQuery();

                if ( Helper::isNonEmptyArray( $preQuery ) ) {
                        $query = array_merge( $query, $preQuery );
                }

                if ( self::$action === "total" ) {
                        $query[ 'number' ] = -1;
                        $query[ 'count' ]  = true;
                } elseif ( self::$action === "preview" ) {
                        $query[ 'offset' ] = Helper::toInt( Helper::_post( 'row' ) ) > 0 ? Helper::toInt( Helper::_post( 'row' ) ) - 1 : 0;
                        $query[ 'number' ] = 1;
                } else {
                        $query[ 'offset' ] = Settings::getLog( 'processed' );
                        $query[ 'number' ] = Settings::recordsPerIteration();
                }

                
                return \apply_filters( 'Wpie/Export/Comment/Query', $query, Settings::getContentType() );
        }

        
        public static function setUniqueComments( $data = null ) {

                $field = " DISTINCT `" . DB::wpdb()->comments . "`.`comment_ID` ";

                if ( self::$action === "total" ) {

                        $data[ 'fields' ] = " COUNT( " . $field . " ) as total ";
                } else {
                        $data[ 'fields' ] = $field;
                }

                return $data;
        }
}
