<?php



namespace WpieApp\Modules\Export\Controller\Items\Post\Fields;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Base\Fields\InterfaceField;
use WpieApp\Modules\Export\Controller\Items\Base\Fields\Meta as BaseMeta;

defined( 'WPIE__FILE__' ) || exit;


class Meta extends BaseMeta implements InterfaceField {

        
        public static function get() {


                
                return \apply_filters( 'Wpie/Export/Post/Fields/Meta', parent::get(), Settings::getContentType() );
        }

        
        protected static function getMetaKeys( $contentType = '' ) {

                
                $types = \apply_filters( 'Wpie/Export/Post/Fields/Meta/PostTypes', $contentType );

                if ( Helper::isEmpty( $types ) ) {
                        return [];
                }

                $postTypes = "";

                if ( is_array( $types ) ) {

                        foreach ( $types as $type ) {
                                $postTypes .= DB::wpdb()->prepare( '%s', $type ) . ",";
                        }

                        $postTypes = rtrim( $postTypes, "," );
                } else {
                        $postTypes = DB::wpdb()->prepare( '%s', $types );
                }

                
                $limit = \apply_filters( 'Wpie/Export/Post/Fields/Meta/Limit', 500 );

                $limit = is_numeric( $limit ) ? DB::wpdb()->prepare( '%d', $limit ) : 500;

                $excludes = self::getExcludesMetaQuery( $types );

                $keys = DB::wpdb()->get_col(
                        "SELECT DISTINCT `postmeta`.`meta_key`
				FROM " . DB::wpdb()->postmeta . " AS `postmeta`
				LEFT JOIN " . DB::wpdb()->posts . " AS `posts` ON ( `posts`.`ID` = `postmeta`.`post_id` )
				WHERE `posts`.`post_type` IN ( " . $postTypes . ")
                                        $excludes
                                ORDER BY `postmeta`.`meta_key`
				LIMIT " . $limit
                );

                return $keys;
        }

        
        protected static function getExcludesMeta( $contentType = '' ) {

                $excludes = array_merge(
                        [ '_thumbnail_id' ],
                        parent::getExcludesMeta()
                );

                
                $excludes = apply_filters( 'Wpie/Export/Post/Fields/Meta/Excludes', $excludes, $contentType );

                return Helper::isNonEmptyArray( $excludes ) ? array_unique( $excludes ) : [];
        }

        
        protected static function getExcludesMetaQuery( $contentType = '' ) {

                $query = array_merge(
                        [
                                " AND `posts`.`post_status` NOT IN ( 'trash' , 'auto-draft' ) ",
                                " AND `postmeta`.`meta_key` NOT LIKE '_edit%' ",
                                " AND `postmeta`.`meta_key` NOT LIKE '_oembed_%' ",
                                " AND `postmeta`.`meta_value` != '' ",
                        ],
                        parent::getExcludesMetaQuery() );

                $keys = DB::prepareData( static::getExcludesMeta( $contentType ) );

                if ( Helper::isNonEmptyStr( $keys ) ) {
                        $query[] = " AND `postmeta`.`meta_key` NOT IN ( " . $keys . " ) ";
                }

                
                $query = \apply_filters( 'Wpie/Export/Post/Fields/Meta/Query/Where', $query, $contentType );

                return Helper::isNonEmptyArray( $query ) ? implode( " ", array_unique( $query ) ) : "";
        }
}
