<?php



namespace WpieApp\Modules\Export\Controller\Items\Taxonomy;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Export\Helpers\Helper;
use WpieApp\Modules\Export\Controller\Settings;
use WpieApp\Modules\Export\Controller\Items\Base\Engine\Base;

defined( 'WPIE__FILE__' ) || exit;


class Engine extends Base {

        
        protected static function getData() {

                global $wp_version;

                
                \do_action( 'Wpie/Export/Taxonomy/Start', Settings::getContentType() );

                $query = self::buildQuery();

                if ( !Helper::isNonEmptyArray( $query ) ) {
                        return false;
                }

                self::initFilter();
                self::addRemoveFilters();

                if ( version_compare( $wp_version, '4.5.0', '<' ) ) {
                        // Ignoring deprecated parameter warning for get_terms() 
                        // since this code is only executed for WordPress versions lower than 4.5.0
                        // phpcs:ignore WordPress.WP.DeprecatedParameters.Get_termsParam2Found
                        $data = \get_terms( $query[ 'taxonomy' ], $query );
                } else {
                        $data = \get_terms( $query );
                }

                self::addRemoveFilters( 'remove' );

                if ( self::$action === "total" ) {
                        return Helper::toInt( $data );
                }

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        $data = [];
                }

                // Clear memory
                unset( $query );

                return static::initDataCenter( $data );
        }

        
        protected static function initDataCenter( $data = [] ) {

                return DataCenter::init( $data, self::$action );
        }

        
        private static function addRemoveFilters( $action = "add" ) {

                $fn = ($action === "remove" ? "remove_filter" : "add_filter");

                // Apply filter rules
                $fn( 'terms_clauses', [ __CLASS__, 'addWhereJoin' ] );

                $fn( 'get_terms_fields', [ __CLASS__, 'getDbField' ] );
        }

        
        private static function initFilter() {

                
                \do_action( 'Wpie/Export/Taxonomy/Filter/Start', Settings::getContentType() );

                Filter::init();

                
                \do_action( 'Wpie/Export/Taxonomy/Filter/Init', Settings::getContentType() );

                static::initBaseFilter();

                self::$where = Filter::getWhere();
                self::$join  = Filter::getJoin();
        }

        
        protected static function buildQuery() {

                $query = [
                        'taxonomy'   => Settings::getContentType(),
                        'orderby'    => 'id',
                        'order'      => 'ASC',
                        'hide_empty' => false,
                        'fields'     => 'ids'
                ];

                $preQuery = parent::buildQuery();

                if ( Helper::isNonEmptyArray( $preQuery ) ) {
                        $query = array_merge( $query, $preQuery );
                }

                if ( self::$action === "total" ) {
                        $query[ 'number' ] = 0;
                        $query[ 'fields' ] = 'count';
                } elseif ( self::$action === "preview" ) {
                        $query[ 'offset' ] = Helper::toInt( Helper::_post( 'row' ) ) > 0 ? Helper::toInt( Helper::_post( 'row' ) ) - 1 : 0;
                        $query[ 'number' ] = 1;
                } else {
                        $query[ 'offset' ] = Settings::getLog( 'processed' );
                        $query[ 'number' ] = Settings::recordsPerIteration();
                }


                
                return \apply_filters( 'Wpie/Export/Taxonomy/Query', $query, Settings::getContentType() );
        }

        
        public static function getDbField() {

                $field = 'DISTINCT `t`.`term_id`';

                if ( self::$action === "total" ) {
                        return [ 'count( ' . $field . ' ) as total' ];
                }
                return [ $field ];
        }
}
