<?php



namespace WpieApp\Modules\Import\Controller\ContentType;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\File\Record;
use WpieApp\Modules\Import\Controller\Settings;

defined( 'WPIE__FILE__' ) || exit;


class Base {

        
        protected static $category = '';

        
        protected static $filePrefix = '';

        
        protected static $contentType = '';

        
        protected static $fields = [];

        
        protected static $data = [];

        
        public static function detect() {

                static::setData();

                if ( Helper::isNonEmptyArray( static::$data ) && array_intersect( array_keys( static::$data ), static::$fields ) ) {
                        if ( static::processData() ) {
                                static::setContentType();
                                return true;
                        }
                }

                return false;
        }

        
        public static function processData() {

                return false;
        }

        
        public static function setData() {

                if ( Helper::isNonEmptyArray( static::$data ) ) {
                        return;
                }

                $data = Record::get( "getRow", [ "row" => 1 ] );

                if ( Helper::isNonEmptyArray( $data ) && "xml" === Settings::getFileFormat() ) {

                        $data = self::processXmlData( $data );
                }

                static::$data = $data;

                unset( $data );
        }

        public static function processXmlData( $array = [] ) {

                if ( !Helper::isNonEmptyArray( $array ) ) {
                        return [];
                }

                $result = [];

                // Check if the current element has 'tag' and 'val' keys
                if ( isset( $array[ 'tag' ] ) && isset( $array[ 'val' ] ) ) {
                        $result[ $array[ 'tag' ] ] = is_array( $array[ 'val' ] ) ? '' : $array[ 'val' ];
                }

                // Check if the array has a 'val' key that contains further nested arrays
                if ( !isset( $array[ 'val' ] ) || !is_array( $array[ 'val' ] ) ) {
                        return $result;
                }

                foreach ( $array[ 'val' ] as $item ) {
                        if ( is_array( $item ) ) {
                                // Recursively process each nested item
                                $result = array_merge( $result, self::processXmlData( $item ) );
                        }
                }


                return $result;
        }

        
        public static function setByFilename() {

                $name = Settings::get( 'file' );

                if ( Helper::strStartsWith( static::$filePrefix, strtolower( $name ) ) ) {
                        static::setContentType();
                        return true;
                }

                return false;
        }

        
        public static function setContentType() {

                Settings::set( [ 'content_type' => static::$contentType, 'category' => static::$category ] );
        }
}
