<?php



namespace WpieApp\Modules\Import\Controller;

use WP_Error;
use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\File\Downloader\Manager as BaseDownloader;

defined( 'WPIE__FILE__' ) || exit;


class Downloader {

        
        public static function init() {

                Helper::createDir( WPIE_UPLOAD_IMPORT_DIR );

                if ( !Helper::setWriteble( WPIE_UPLOAD_IMPORT_DIR ) ) {

                        return new WP_Error( 'wpieError', __( 'Uploads folder is not writable', 'wp-import-export' ) );
                }

                $method = Settings::getOption( 'uploder/method' );

                if ( 'local' === $method ) {
                        return self::localDownload();
                }

                $options = [
                        'path' => Settings::getOption( 'uploder/options/path' ),
                        'url'  => Settings::getOption( 'uploder/options/url' ),
                ];

                return BaseDownloader::init( 'download', $options );
        }

        
        public static function localDownload() {

                $parentId = Settings::get( 'parent' );

                $parentDir = DB::wpdb()->get_var( DB::wpdb()->prepare( "SELECT `filedir` FROM " . DB::getPluginTable() . " where `id` = %d", $parentId ) );

                if ( !Helper::isNonEmptyStr( $parentDir ) ) {
                        return new WP_Error( 'wpieError', __( "Unable to find the parent directory", 'wp-import-export' ) );
                }

                $source = Helper::pathJoin( WPIE_UPLOAD_IMPORT_DIR, $parentDir );
                $dest   = Helper::pathJoin( WPIE_UPLOAD_IMPORT_DIR, Settings::get( 'filedir' ) );

                $isSuccess = Helper::copyDir( $source, $dest );

                if ( false === $isSuccess ) {
                        return new WP_Error( 'wpieError', __( "Unable to copy the files", 'wp-import-export' ) );
                }

                Helper::emptyDir( $dest . '/log' );

                Settings::set( 'status', 'paused' );

                return Settings::getFilePath();
        }
}
