<?php



namespace WpieApp\Modules\Import\Controller\Items\Post\Engines;

use WpieApp\Core\Utils\DB;
use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Post\DataCenter;

defined( 'WPIE__FILE__' ) || exit;


class Author {

        
        protected static $cache = [];

        
        private static $pluginUser = 0;

        
        public static function get() {

                if ( !DataCenter::canUpdate( "user/author" ) ) {
                        return DataCenter::isNewItem() ? [ "post_author" => Helper::toInt( self::getPluginUser() ) ] : [];
                }

                $data = DataCenter::get( "user/author/data" );

                $id = self::getUser( $data );

                if ( $id === 0 ) {
                        $id = self::getPluginUser();
                }

                unset( $data );

                return Helper::toInt( $id ) > 0 ? [ "post_author" => Helper::toInt( $id ) ] : [];
        }

        
        private static function getPluginUser() {

                if ( self::$pluginUser > 0 ) {
                        return self::$pluginUser;
                }

                $data = Settings::get( "user" );

                $user = \wp_cache_get( $data, "useremail" );

                if ( $user !== false && isset( $user->ID ) && \absint( $user->ID ) > 0 ) {
                        self::$pluginUser = $user->ID;
                }

                if ( self::$pluginUser === 0 ) {

                        $user = \get_user_by( 'email', $data );

                        if ( $user !== false && isset( $user->ID ) && \absint( $user->ID ) > 0 ) {
                                self::$pluginUser = $user->ID;
                        }
                }

                if ( self::$pluginUser === 0 ) {
                        self::$pluginUser = \get_current_user_id();
                }

                return self::$pluginUser;
        }

        
        private static function getUser( $data = "" ) {

                if ( !Helper::isNonEmptyStr( $data ) ) {
                        return 0;
                }

                $data = trim( $data );

                if ( isset( self::$cache[ $data ] ) ) {
                        return self::$cache[ $data ];
                }

                $fields = [ 'useremail', 'userlogins', 'userslugs' ];

                if ( is_numeric( $data ) && Helper::toInt( $data ) > 0 ) {
                        array_unshift( $fields, 'users' );
                }

                $id = 0;

                foreach ( $fields as $field ) {

                        $user = \wp_cache_get( $data, $field );

                        if ( $user !== false && isset( $user->ID ) && \absint( $user->ID ) > 0 ) {
                                $id = $user->ID;
                                break;
                        }
                }

                if ( $id === 0 ) {

                        $id = DB::wpdb()->get_var(
                                DB::wpdb()->prepare(
                                        "SELECT `ID` FROM " . DB::wpdb()->users . " WHERE `user_email` = %s OR `user_login` = %s OR `user_nicename` = %s LIMIT 1",
                                        $data, $data, $data
                                )
                        );
                }

                if ( count( self::$cache ) > 50 ) {
                        array_shift( self::$cache );
                }

                self::$cache[ $field ] = is_numeric( $id ) ? $id : 0;

                if ( !is_numeric( $id ) || absint( $id ) === 0 ) {
                        return 0;
                }

                return $id;
        }

}
