<?php



namespace WpieApp\Modules\Import\Controller\Items\Post\Engines;

use WpieApp\Modules\Import\Helpers\Helper;
use WpieApp\Modules\Import\Controller\Settings;
use WpieApp\Modules\Import\Controller\Items\Base\Logger;
use WpieApp\Modules\Import\Controller\Items\Post\DataCenter;
//use WpieApp\Modules\Import\Controller\Items\Taxonomy\Search;
use WpieApp\Modules\Import\Controller\Items\Term\Search;

defined( 'WPIE__FILE__' ) || exit;


class Taxonomy {

        
        public static $caching = true;

        
        private static $cache = [];

        
        public static function import() {

                $taxonomies = DataCenter::updateList( "taxonomy" );

                if ( !Helper::isNonEmptyArray( $taxonomies ) ) {
                        return;
                }

                self::prepare( array_keys( $taxonomies ) );

                /* translators: %s: content type */
                Logger::log( sprintf( __( "%s Taxonomies Imported", 'wp-import-export' ), Settings::getContentLabel() ) );
        }

        
        public static function prepare( $taxonomies = [] ) {

                $append = DataCenter::isNewItem() || DataCenter::getFieldSetting( "taxonomy/options/manage-existing" ) !== "append" ? false : true;

                foreach ( $taxonomies as $taxonomy ) {

                        if ( !taxonomy_exists( $taxonomy ) ) {
                                continue;
                        }

                        $data = DataCenter::get( "taxonomy/" . $taxonomy . "/data" );

                        if ( !Helper::isNonEmptyStr( $data ) ) {
                                continue;
                        }

                        $separator = DataCenter::get( "taxonomy/" . $taxonomy . "/separator" );

                        $separator = Helper::isNonEmptyStr( $separator ) ? trim( $separator ) : ",";

                        $terms = self::getTerms( explode( $separator, $data ), $taxonomy );

                        if ( !Helper::isNonEmptyArray( $terms ) ) {
                                continue;
                        }

                        $isTermSet = \wp_set_object_terms( DataCenter::getId(), $terms, $taxonomy, $append );

                        if ( is_wp_error( $isTermSet ) ) {
                                Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> " . $isTermSet->get_error_message() );
                        }
                }
        }

        
        public static function getTerms( $terms, $taxonomy ) {

                $data = [];

                foreach ( $terms as $term ) {

                        $termData = self::getTerm( $term, $taxonomy );

                        if ( is_wp_error( $termData ) ) {
                                continue;
                        }

                        $data = array_merge( $data, $termData );
                }
                return $data;
        }

        
        public static function getTerm( $terms, $taxonomy ) {

                if ( is_taxonomy_hierarchical( $taxonomy ) ) {

                        $separator = DataCenter::get( "taxonomy/" . $taxonomy . "/hierarchy-separator" );

                        $separator = Helper::isNonEmptyStr( $separator ) ? trim( $separator ) : ">";

                        $terms = explode( $separator, $terms );
                }

                if ( !is_array( $terms ) ) {
                        $terms = [ $terms ];
                }

                $data = [];

                $parent = 0;

                foreach ( $terms as $term ) {

                        if ( !Helper::isNonEmptyStr( $term ) ) {
                                continue;
                        }

                        $term = trim( $term );

                        $cache = self::getCache( $term, $taxonomy, $parent );

                        //    $id = Search::getTermId( $term, $taxonomy, null, $parent );
                        $id = ($cache > 0) ? $cache : Search::findTerm( '', $term, $taxonomy, ($parent > 0 ? [ 'parent' => $parent ] : [] ) );

                        if ( is_numeric( $id ) && \absint( $id ) > 0 ) {
                                $data[] = \absint( $id );
                                $parent = \absint( $id );
                                continue;
                        }


                        $termData = \wp_insert_term( $term, $taxonomy, [ 'parent' => $parent ] );

                        if ( is_wp_error( $termData ) ) {

                                Logger::log( "<strong>" . __( "ERROR", 'wp-import-export' ) . "</strong> " . $termData->get_error_message() );
                                $data = $termData;
                                break;
                        }

                        if ( !is_array( $termData ) || !isset( $termData[ 'term_id' ] ) || !is_numeric( $termData[ 'term_id' ] ) ) {
                                continue;
                        }

                        $termId = \absint( $termData[ 'term_id' ] );

                        self::setCache( $termId, $term, $taxonomy, $parent );

                        $data[] = $termId;

                        $parent = $termId;
                }

                return $data;
        }

        
        public static function getCache( $term = '', $taxonomy = '', $parent = '' ) {

                if ( !self::$caching ) {
                        return 0;
                }

                if ( !isset( self::$cache[ $taxonomy ] ) ) {
                        self::$cache[ $taxonomy ] = [];
                }
                if ( !isset( self::$cache[ $taxonomy ][ $term ] ) ) {
                        return 0;
                }

                $data = isset( self::$cache[ $taxonomy ][ $term ][ 'data' ] ) ? self::$cache[ $taxonomy ][ $term ][ 'data' ] : [];

                if ( !Helper::isNonEmptyArray( $data ) ) {
                        return 0;
                }

                $id = 0;

                foreach ( $data as $termData ) {

                        if ( !isset( $termData[ 'parent' ] ) || $parent !== $termData[ 'parent' ] ) {
                                continue;
                        }

                        $id = isset( $termData[ 'id' ] ) ? $termData[ 'id' ] : 0;

                        break;
                }
                return $id;
        }

        
        public static function setCache( $id, $term = '', $taxonomy = '', $parent = '' ) {

                if ( !self::$caching ) {
                        return 0;
                }

                if ( !isset( self::$cache[ $taxonomy ] ) ) {
                        self::$cache[ $taxonomy ] = [];
                }
                if ( !isset( self::$cache[ $taxonomy ][ $term ] ) ) {
                        self::$cache[ $taxonomy ][ $term ] = [];
                }

                if ( !isset( self::$cache[ $taxonomy ][ $term ][ 'data' ] ) ) {
                        self::$cache[ $taxonomy ][ $term ][ 'data' ] = [];
                }

                self::$cache[ $taxonomy ][ $term ][ 'data' ][] = [ 'id' => $id, 'parent' => $parent ];
        }
}
