<?php



namespace WpieApp\Providers;

use WpieApp\Core\Admin\Admin;
use WpieApp\Core\Helpers\Helper;
use WpieApp\Extensions\Manager as Extensions;

defined( 'WPIE__FILE__' ) || exit;


class Plugin {

        
        public static function preInit() {
                return Admin::preInit();
        }

        
        public static function init() {

                if ( !Admin::requirementCheck() ) {
                        return;
                }

                if ( Cron::isValidRequest() ) {
                        self::load();
                        Cron::init();
                        return;
                }

                if ( !Helper::isValidRequest() ) {
                        return;
                }

                self::load();

                if ( Helper::isAjax() ) {

                        self::registerAjaxRequest();
                        return;
                } else if ( Helper::isApiRequest() ) {

                        self::initRequest();
                        return;
                }

                self::initMiddlewares();

                Menu::init();
        }

        
        private static function load() {

                Admin::init();

                GlobalTasks::init();

                Extensions::load();
        }

        
        private static function initMiddlewares() {

                $findMiddlewareClasses = glob( WPIE_MODULES_DIR . '/*/Middleware.php' );

                $modulesDir = str_replace( '\\', '/', realpath( WPIE_MODULES_DIR ) );

                foreach ( $findMiddlewareClasses as $middlewareClass ) {
                        $middlewareClass = str_replace( '\\', '/', realpath( $middlewareClass ) );

                        if ( strpos( $middlewareClass, $modulesDir ) !== 0 ) {
                                continue;
                        }
                        $getModuleName = substr( $middlewareClass, strlen( rtrim( $modulesDir, '/' ) ) + 1 );
                        $getModuleName = explode( '/', $getModuleName );

                        $moduleName = $getModuleName[ 0 ];

                        $middlewareClassName = "\\WpieApp\\Modules\\{$moduleName}\\Middleware";

                        if ( !class_exists( $middlewareClassName ) ) {
                                continue;
                        }

                        new $middlewareClassName();
                }
        }

        
        private static function registerAjaxRequest() {

                $action = Helper::sanitizeiKey( Helper::_post( 'action' ) );

                add_action( 'wp_ajax_' . $action, [ __CLASS__, "initRequest" ] );
        }

        
        public static function initRequest() {

                $activeModule = Helper::getActiveModule();

                // Nothing to do if Module not found
                if ( Helper::isEmptyStr( $activeModule ) ) {
                        return false;
                }

                if ( !Helper::verifyNonce() ) {
                        Helper::ajaxError( __( 'Session expired. Please Refresh Page.', 'wp-import-export' ) );
                }

                if ( !Helper::userHasPermission() ) {
                        Helper::ajaxError( __( 'Permission denied!', 'wp-import-export' ) );
                }

                $moduleMainClass = '\\WpieApp\\Modules\\' . $activeModule . '\\Controller\\Ajax';

                $action = Helper::sanitizeiKey( Helper::_post( 'action' ) );

                $method = Helper::leftTrim( $action, Helper::PLUGIN_PREFIX );

                if ( method_exists( $moduleMainClass, $method ) ) {
                        $moduleMainClass::$method();
                } else {
                        /* translators: 1: Action name. 2: module name */
                        Helper::ajaxError( sprintf( __( '%1$s - action not exists in %2$s module!', 'wp-import-export' ), esc_html( $method ), esc_html( $activeModule ) ) );
                }
        }
}
